Museum

Home

Lab Overview

Retrotechnology Articles

Online Manuals

⇒ () — AMT DAP 4.1S

Media Vault

Software Library

Restoration Projects

Artifacts Sought



MACRO                  PSAM/DAPDB Commands                  MACRO



NAME
     macro - execute a series of commands held in a file

SYNOPSIS
     macro <filename>

     <filename>

DESCRIPTION
     The macro command reads commands from the  file  <filename>.
     The  commands  in  the macro file are executed one line at a
     time starting from the first line. If a command in the macro
     file  causes  an  error no more macro commands are executed.
     Macro interpretation is also terminated by the commands con-
     tinue,  step, stepi, next and quit.  History substitution is
     not allowed in commands read from macro files.

     Prior to executing a command from a macro file the following
     line is displayed,

               (<filename>: <command>)

     where <filename> is the macro file from  which  the  command
     was read and <command> is the command about to be executed.

     The macro command searches for the file  <filename>  in  the
     following  way. If an absolute file name (one beginning with
     '/') or a filename relative to the current working directory
     (beginning  with  './' or '../') or a filename relative to a
     user's home  directory  (beginning  with  '~/'  or  '~<user-
     name>/')   is  specified  then  the  named  file  is  sought
     directly. Otherwise the file is sought in each of the direc-
     tories  specified  in  the  current  Source_path environment
     variable.

     Macro files may themselves contain macro commands.   Nesting
     of macro commands is allowed up to a maximum depth of 10.

SEE ALSO
     set, interpreter















AMT Release 4.1S   Last change: 11th May 1989                   1



Typewritten Software • bear@typewritten.org • Edmonds, WA 98026